@@ -44,6 +44,9 @@ my %typemap = (
     uint     => "GLuint",
     ushort   => "GLushort",
     DMbuffer => "void *",
+    # Nvidia video output fsck up
+    int64EXT => "GLint64EXT",
+    uint64EXT=> "GLuint64EXT",
 
     # ARB VBO introduces these.
 
@@ -57,6 +60,12 @@ my %typemap = (
     charARB => "GLcharARB",
     handleARB => "GLhandleARB",
 
+    # OpenGL 3.2 and GL_ARB_sync
+
+    int64  => "GLint64",
+    uint64 => "GLuint64",
+    sync   => "GLsync",
+
     # GLX 1.3 defines new types which might not be available at compile time
 
     #GLXFBConfig   => "void*",
@@ -109,11 +118,14 @@ my %fnc_ignore_list = (
     "ProgramLocalParameter4fARB"    => "ARB_vertex_program",
     "ProgramLocalParameter4fvARB"   => "ARB_vertex_program",
     "ProgramStringARB"              => "ARB_vertex_program",
+    "glXCreateContextAttribsARB"    => "ARB_create_context_profile",
+    "wglCreateContextAttribsARB"    => "WGL_ARB_create_context_profile",
 );
 
 my %regex = (
     eofnc    => qr/(?:\);?$|^$)/, # )$ | );$ | ^$
     extname  => qr/^[A-Z][A-Za-z0-9_]+$/,
+    none     => qr/^\(none\)$/,
     function => qr/^(.+) ([a-z][a-z0-9_]*) \((.+)\)$/i,
     prefix   => qr/^(?:[aw]?gl|glX)/, # gl | agl | wgl | glX
     tprefix  => qr/^(?:[AW]?GL|GLX)_/, # GL_ | AGL_ | WGL_ | GLX_
@@ -128,8 +140,10 @@ sub normalize_prototype
 {
     local $_ = join(" ", @_);
     s/\s+/ /g;                # multiple whitespace -> single space
+    s/\<.*\>//g;              # remove <comments> from direct state access extension
+    s/\<.*$//g;               # remove incomplete <comments> from direct state access extension
     s/\s*\(\s*/ \(/;          # exactly one space before ( and none after
-    s/\s*\)\s*/\)/;           # no after before or after )
+    s/\s*\)\s*/\)/;           # no space before or after )
     s/\s*\*([a-zA-Z])/\* $1/; # "* identifier"
     s/\*wgl/\* wgl/;          # "* wgl"
     s/\*glX/\* glX/;          # "* glX"
@@ -168,7 +182,13 @@ sub parse_spec($)
 
         "Name Strings" => sub {
             # Add extension name to extension list
-            # Does this look even plausible?
+        
+           # Initially use $extname if (none) specified
+            if (/$regex{none}/)
+            {
+                $_ = $extname;
+            }
+
             if (/$regex{extname}/)
             {
                 # prefix with "GL_" if prefix not present
@@ -288,10 +308,11 @@ foreach my $spec (sort @speclist)
     {
         my $info = "$ext_dir/" . $ext;
         open EXT, ">$info";
-        print EXT $ext . "\n";
-		my $specname = $spec;
-		$specname =~ s/registry\///;
-        print EXT $reg_http . $specname . "\n";
+        print EXT $ext . "\n";                       # Extension name
+        my $specname = $spec;
+        $specname =~ s/registry\///;
+        print EXT $reg_http . $specname . "\n";      # Extension info URL
+        print EXT $ext . "\n";                       # Extension string
 
         my $prefix = $ext;
         $prefix =~ s/^(.+?)(_.+)$/$1/;
@@ -299,7 +320,7 @@ foreach my $spec (sort @speclist)
         {
             if ($token =~ /^$prefix\_.*/i)
             {
-                print EXT "\t" . $token . " " . ${%{$tokens}}{$token} . "\n";
+                print EXT "\t" . $token . " " . ${\%{$tokens}}{$token} . "\n";
             }
         }
         foreach my $function (sort keys %{$functions})
